from src.create_with_eeriecloud import *
from pystac_client import Client as psc
from utils.defaults import *
from utils.api_interaction import *
import json
import fsspec

STAC_COLLECTION_CONF=dict(
    project_id="EERIE",
    activity_id="EERIE",
    start="1850",
    end="2100",
    description_default=(
    "The EERIE project, running from January 2023 to December 2026, will reveal and quantify the role of ocean mesoscale processes in shaping the climate trajectory over seasonal to centennial time scales. To this end EERIE will develop a new generation of Earth System Models (ESMs) that are capable of explicitly representing a crucially important, yet unexplored regime of the Earth system – the ocean mesoscale. Leveraging the latest advances in science and technology, EERIE will substantially improve the ability of such ESMs to faithfully represent the centennial-scale evolution of the global climate, especially its variability, extremes and how tipping points may unfold under the influence of the ocean mesoscale."
                ),
    description_key="description"
    #institution_id=None,
    #source_id=None
)
L_DELETE=True

cat=psc.open(
    defaults["STAC_BASE_URL"]
)

if L_DELETE:
    xp_exps=list(cat.get_all_collections())
    print("Delete collections")
    for xp_exp in xp_exps:
        if xp_exp.id.startswith(STAC_COLLECTION_CONF["project_id"]):
            api_delete_collection(defaults["STAC_BASE_URL"],xp_exp.id)

            
dslist=json.load(fsspec.open(defaults["EERIE_CLOUD_URL"]).open())
exp_items=[a for a in dslist if not any(a.startswith(b) for b in ["nextgems","cosmo","era"])]
source_collections=sorted(list(set(
        [
            '.'.join(a.split('.')[0:3])
            for a in exp_items
        ]
)))

for source_collection in source_collections:
    print(f"Start process for {source_collection}")

    local_conf=copy(STAC_COLLECTION_CONF)
    local_conf["source_id"]=source_collection.split('.')[0]
    if "icon" in local_conf["source_id"].lower() and not local_conf.get("institution_id",None):
        local_conf["institution_id"]="MPI-M"
    if "ifs-fesom" in local_conf["source_id"].lower() and not local_conf.get("institution_id",None):
        local_conf["institution_id"]="AWI"
    if "ifs-nemo" in local_conf["source_id"].lower() and not local_conf.get("institution_id",None):
        local_conf["institution_id"]="BSC"
    local_conf["experiment_id"]=source_collection.split('.')[1]
    local_conf["version_id"]=source_collection.split('.')[2]
    if local_conf["version_id"][0] != "v":
        print(f"Collection version does not start with 'v': {local_conf['version_id']}")
        continue
    
    #print(f"Delete collection {stac_collection_id}")
    #try:
    #    api_delete_collection(defaults["STAC_BASE_URL"],stac_collection_id)
    #except:
    #    pass

    
    print("Create items")
    items=create_items_from_eeriecloud(
        local_conf["project_id"],
        filterstring=source_collection
    )
    print(f"Created {len(items)} items")
    
    print("Create new collection from eerie cloud")
    
    py_template_item=pystac.item.Item.from_dict(items[0])
    stac_collection_id_raw=get_collection_id_from_item(
        local_conf,
        template_item=py_template_item
    )
    stac_collection_id=stac_collection_id_raw.replace('<','').replace('>','')

    collection=create_collection_from_eerieclouditem(
        local_conf,
        stac_collection_id_raw,
        template_item=py_template_item
    )

    print("Ingest new collection")
    api_create_or_update_collection(
        defaults["STAC_BASE_URL"],
        stac_collection_id,
        collection
    )

    for item_json in items:
        item_json["collection"]=stac_collection_id

    print("Ingest items")
    for item in items:    
        try:
            api_create_or_update_item(
            #api_create_item(
                defaults["STAC_BASE_URL"],
                stac_collection_id,
                item
            )
        except Exception as e:
            print(item["id"])
            print(e)

        
        