from utils.defaults import *
from utils.api_interaction import *
from utils.defaults import *
from .create_collection import *

import pystac
import fsspec
import json
from utils.defaults import *
from utils.misc import *

dslist=json.load(fsspec.open(defaults["EERIE_CLOUD_URL"]).open())

def clean_eeriecloud_item(item_json: dict)->dict:
    if item_json.get("default_var",None):
        del item_json["default_var"]
    for v in list(item_json["properties"]["cube:variables"].keys()):
        del item_json["properties"]["cube:variables"][v]["attrs"]
    return item_json

def set_eeriecloud_item_title(project_id: str, exp_item: pystac.item.Item, default_title: str) -> str:
    if project_id.lower() == "era" :
        #item_json["properties"]["description"]="Data from "+item_json["properties"]["title"]+accguide
        ititle=' '.join(exp_item.id.split('.')[-1].split('_'))
    else:
        ititle=default_title
    ititle+=defaults["STAC_ITEM_XPUBLISH_TITLE_SUFFIX"]
    return ititle

def create_items_from_eeriecloud(project_id: str, filterstring: str = None) -> list:
    global dslist
    exp_items=[a for a in dslist if a.startswith(project_id.lower())]
    if project_id == "EERIE":
        exp_items=[a for a in dslist if not any(a.startswith(b) for b in ["nextgems","cosmo","era"])]
    if filterstring:
        exp_items=[a for a in exp_items if filterstring in a]
    items=[]
    for exp_item_name in exp_items:
        exp_item = pystac.item.Item.from_file(
            f"{defaults['EERIE_CLOUD_URL']}/{exp_item_name}/stac"
        )
        id_item=defaults["STAC_ITEM_ID_XPUBLISH_PREFIX"]+exp_item.id
        item_json=exp_item.to_dict()
        item_json["id"]=id_item
        item_json["properties"]["title"]=set_eeriecloud_item_title(
            project_id, 
            exp_item, 
            ' '.join(item_json["properties"]["title"].split(' ')[3:])
        )
        item_providers=get_providers(item_json)
        if item_providers:
            item_json["properties"]["providers"]=item_providers

        item_json=clean_eeriecloud_item(item_json)
        item_json["links"]=[]
        items.append(item_json)
    return items

def create_collection_from_eerieclouditem(
    stac_collection_conf:dict,
    stac_collection_id_raw:str,
    description:str = None,
    template_item:pystac.item.Item = None
) -> dict:
    
    if not description:
        description=get_collection_description_from_item(
            stac_collection_conf,
            template_item=template_item # This is then taken from eeriecloud
        )
    
    title=None
    stac_collection_id=stac_collection_id_raw
    if '<' in stac_collection_id_raw or '>' in stac_collection_id_raw:
        stac_collection_id=stac_collection_id_raw.replace('<','').replace('>','')
        title=stac_collection_id_raw.replace('<','').replace('>-',' ').replace('>','')

    collection=create_collection_defaults( #uses id as title and description
        stac_collection_id,
        start=stac_collection_conf["start"],
        end=stac_collection_conf["end"],
        description=description,
        title=title
    )
    
    collection=get_and_set_collection_providers_from_item(
        stac_collection_conf, 
        collection,
        template_item=None #taken from eeriecloud
    )
    
    return collection